==> xkeycaps-2.29-3.tar.gz: xkeycaps-2.29/kbds/explorer-caps.h <==
/* xkeycaps, Copyright (c) 1991, 1992, 1993 Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the key surfaces of the TI Explorer Lisp Machine
 * keyboard.
 */

static struct key_strings explorer_caps [] = {

  /* Row 0 */

  {"Help", 0},
  {"System", 0},
  {"Network", 0},
  {"Status", 0},
  {"Term", 0},
  {"Caps", "Lock", 0},
  {"Bold", "Lock", 0},
  {"Italic", "Lock", 0},
  {"Mode", "Lock", 0},
  {"Clear", "Screen", 0},
  {"Clear", "Input", 0},
  {"Undo", 0},
  {"End", 0},
  {"Left", 0},
  {"Middle", 0},
  {"Right", 0},
  {"F1", 0},
  {"F2", 0},
  {"F3", 0},
  {"F4", 0},

  /* Row 2 */

  {"Resume", 0},
  {"Escape", 0},
  {"!", "1", 0},
  {"@", "2", 0},
  {"#", "3", 0},
  {"$", "4", 0},
  {"%", "5", 0},
  {"^", "6", 0},
  {"&", "7", 0},
  {"*", "8", 0},
  {"(", "9", 0},
  {")", "0", 0},
  {"_", "-", 0},
  {"+", "=", 0},
  {"{", "`", 0},
  {"}", "~", 0},
  {"=", 0},
  {"+", 0},
  {"Space", 0},
  {"Tab", 0},

  /* Row 3 */

  {"Break", 0},
  {"Tab", 0},
  {"Q", 0},
  {"W", 0},
  {"E", 0},
  {"R", 0},
  {"T", 0},
  {"Y", 0},
  {"U", 0},
  {"I", 0},
  {"O", 0},
  {"P", 0},
  {"[", "(", 0},
  {"]", ")", 0},
  {"|", "\\", 0},
  {"UpArrow", 0},
  {"7", 0},
  {"8", 0},
  {"9", 0},
  {"-", 0},

  /* Row 4 */

  {"Abort", 0},
  {"Rubout", 0},
  {"A", 0},
  {"S", 0},
  {"D", 0},
  {"F", 0},
  {"G", 0},
  {"H", 0},
  {"J", 0},
  {"K", 0},
  {"L", 0},
  {":", ";", 0},
  {"\"", "'", 0},
  {"Return", 0},
  {"Line ", "Feed", 0},
  {"LeftArrow", 0},
  {"Purge", "Disk", 0},
  {"RightArrow", 0},
  {"4", 0},
  {"5", 0},
  {"6", 0},
  {",", 0},

  /* Row 5 */

  {"Sym-", "bol", 0},
  {"Shift", 0},
  {"Z", 0},
  {"X", 0},
  {"C", 0},
  {"V", 0},
  {"B", 0},
  {"N", 0},
  {"M", 0},
  {"<", ",", 0},
  {">", ".", 0},
  {"?", "/", 0},
  {"Shift", 0},
  {"Symbol", 0},
  {"DownArrow", 0},
  {"1", 0},
  {"2", 0},
  {"3", 0},
  {"Enter", 0},

  /* Row 6 */

  {"Hyper", 0},
  {"Super", 0},
  {"Meta", 0},
  {"Ctrl", 0},
  {" ", 0},
  {"Ctrl", 0},
  {"Meta", 0},
  {"Super", 0},
  {"Hyper", 0},
  {"0", 0},
  {".", 0}
};

==> xkeycaps_2.42.orig.tar.gz: xkeycaps-2.42/kbds/explorer-caps.h <==
/* xkeycaps, Copyright (c) 1991, 1992, 1993 Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the key surfaces of the TI Explorer Lisp Machine
 * keyboard.
 */

static const struct key_strings explorer_caps [] = {

  /* Row 0 */

  {"Help", 0},
  {"System", 0},
  {"Network", 0},
  {"Status", 0},
  {"Term", 0},
  {"Caps", "Lock", 0},
  {"Bold", "Lock", 0},
  {"Italic", "Lock", 0},
  {"Mode", "Lock", 0},
  {"Clear", "Screen", 0},
  {"Clear", "Input", 0},
  {"Undo", 0},
  {"End", 0},
  {"Left", 0},
  {"Middle", 0},
  {"Right", 0},
  {"F1", 0},
  {"F2", 0},
  {"F3", 0},
  {"F4", 0},

  /* Row 2 */

  {"Resume", 0},
  {"Escape", 0},
  {"!", "1", 0},
  {"@", "2", 0},
  {"#", "3", 0},
  {"$", "4", 0},
  {"%", "5", 0},
  {"^", "6", 0},
  {"&", "7", 0},
  {"*", "8", 0},
  {"(", "9", 0},
  {")", "0", 0},
  {"_", "-", 0},
  {"+", "=", 0},
  {"{", "`", 0},
  {"}", "~", 0},
  {"=", 0},
  {"+", 0},
  {"Space", 0},
  {"Tab", 0},

  /* Row 3 */

  {"Break", 0},
  {"Tab", 0},
  {"Q", 0},
  {"W", 0},
  {"E", 0},
  {"R", 0},
  {"T", 0},
  {"Y", 0},
  {"U", 0},
  {"I", 0},
  {"O", 0},
  {"P", 0},
  {"[", "(", 0},
  {"]", ")", 0},
  {"|", "\\", 0},
  {"UpArrow", 0},
  {"7", 0},
  {"8", 0},
  {"9", 0},
  {"-", 0},

  /* Row 4 */

  {"Abort", 0},
  {"Rubout", 0},
  {"A", 0},
  {"S", 0},
  {"D", 0},
  {"F", 0},
  {"G", 0},
  {"H", 0},
  {"J", 0},
  {"K", 0},
  {"L", 0},
  {":", ";", 0},
  {"\"", "'", 0},
  {"Return", 0},
  {"Line ", "Feed", 0},
  {"LeftArrow", 0},
  {"Purge", "Disk", 0},
  {"RightArrow", 0},
  {"4", 0},
  {"5", 0},
  {"6", 0},
  {",", 0},

  /* Row 5 */

  {"Sym-", "bol", 0},
  {"Shift", 0},
  {"Z", 0},
  {"X", 0},
  {"C", 0},
  {"V", 0},
  {"B", 0},
  {"N", 0},
  {"M", 0},
  {"<", ",", 0},
  {">", ".", 0},
  {"?", "/", 0},
  {"Shift", 0},
  {"Symbol", 0},
  {"DownArrow", 0},
  {"1", 0},
  {"2", 0},
  {"3", 0},
  {"Enter", 0},

  /* Row 6 */

  {"Hyper", 0},
  {"Super", 0},
  {"Meta", 0},
  {"Ctrl", 0},
  {" ", 0},
  {"Ctrl", 0},
  {"Meta", 0},
  {"Super", 0},
  {"Hyper", 0},
  {"0", 0},
  {".", 0}
};
